//=============================================================================
// File: BLINK_INTR.C
// Func: CardS12 blinking LED Demo using OC2 Interrupt
// Copr: (C)2002-2003 by Oliver Thamm, MCT Elektronikladen
//       http://www.elektronikladen.de
// Link: Use the "Custom" Linker Setting with the following options:
//       Program Memory = 0x8000
//       Data Memory    = 0x3000
//       Stack Pointer  = 0x3E00           
// Rem.: This program is supposed to run under the TwinPeeks Monitor,
//       so an Interrupt Vector File (e.g. VECTORS.C) is *not* included.
//       Just convert the S19 file using SRECCVT, then load it ("L")
//       using the monitor and start the program ("G 8000").
//=============================================================================

//--------------------------------------------------------------

#include <stdio.h>
#include "hcs12dp256.h"

//--------------------------------------------------------------

#pragma interrupt_handler isrOC2
void isrOC2(void) {

    TFLG1 = 0x04;   // clear OC2 Intr Flag
    TC2 += 31250u;  // 1 interrupt every 31250 timer ticks (0.5s)
    PTH ^= 0x80;    // toggle LED
    }

//--------------------------------------------------------------

void main(void) {

    // install OC2 pseudo vector in RAM
    // (if running with TwinPEEKs monitor)
    *((unsigned char *)0x3fe2) = 0x06;  // JMP opcode
    *((void (**)(void))0x3fe3) = isrOC2;

    // make PTH[7] an Output to drive the LED
    DDRH |= 0x80;

    // Timer Setup
    TSCR1  = 0x80;  // Timer enable
    TSCR2  = 0x07;  // Prescaler = 128 (1 timer tick every 16s)
    TCTL2  = 0x00;  // TC2 disconnected from Pin
    TIOS  |= 0x04;  // TC2 is Output Compare
    TIE   |= 0x04;  // TC2 Interrupt enable

    // enable Interrupts
    asm("cli");

    // loop endless (and let the interrupt work)
    while(1) ;
    }

//==============================================================

